==> threeagent-0.0.1-20190116.013136-2.jar: public/js/out/threeagent/impl/threejs.js <==
// Compiled by ClojureScript 1.10.439 {}
goog.provide('threeagent.impl.threejs');
goog.require('cljs.core');
goog.require('threeagent.impl.util');
threeagent.impl.threejs.perspective_camera = (function threeagent$impl$threejs$perspective_camera(fov,aspect,near,far){
return (new THREE.PerspectiveCamera(fov,aspect,near,far));
});
threeagent.impl.threejs.point_light = (function threeagent$impl$threejs$point_light(c,i,d){
return (new THREE.PointLight(c,i,d));
});
threeagent.impl.threejs.hemisphere_light = (function threeagent$impl$threejs$hemisphere_light(sky_color,ground_color,intensity){
return (new THREE.HemisphereLight(sky_color,ground_color,intensity));
});
threeagent.impl.threejs.box_geometry = (function threeagent$impl$threejs$box_geometry(x,y,z){
return (new THREE.BoxGeometry(x,y,z));
});
threeagent.impl.threejs.plane_geometry = (function threeagent$impl$threejs$plane_geometry(width,height,segments_width,segments_height){
return (new THREE.PlaneGeometry(width,height,segments_width,segments_height));
});
threeagent.impl.threejs.sphere_geometry = (function threeagent$impl$threejs$sphere_geometry(radius,width_seg,height_seg){
return (new THREE.SphereGeometry(radius,width_seg,height_seg));
});
threeagent.impl.threejs.text_geometry = (function threeagent$impl$threejs$text_geometry(text,cfg){
return (new THREE.TextGeometry(text,cljs.core.clj__GT_js.call(null,cfg)));
});
threeagent.impl.threejs.mesh_basic_material = (function threeagent$impl$threejs$mesh_basic_material(c){
return (new THREE.MeshBasicMaterial(cljs.core.clj__GT_js.call(null,c)));
});
threeagent.impl.threejs.mesh_phong_material = (function threeagent$impl$threejs$mesh_phong_material(c){
return (new THREE.MeshPhongMaterial(cljs.core.clj__GT_js.call(null,c)));
});
threeagent.impl.threejs.mesh = (function threeagent$impl$threejs$mesh(geo,mat){
return (new THREE.Mesh(geo,mat));
});
threeagent.impl.threejs.object = (function threeagent$impl$threejs$object(){
return (new THREE.Object3D());
});
threeagent.impl.threejs.group = (function threeagent$impl$threejs$group(){
return (new THREE.Group());
});
threeagent.impl.threejs.vec3 = (function threeagent$impl$threejs$vec3(var_args){
var G__23886 = arguments.length;
switch (G__23886) {
case 1:
return threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 3:
return threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
case 0:
return threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$0();

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$1 = (function (p__23887){
var vec__23888 = p__23887;
var x = cljs.core.nth.call(null,vec__23888,(0),null);
var y = cljs.core.nth.call(null,vec__23888,(1),null);
var z = cljs.core.nth.call(null,vec__23888,(2),null);
return (new THREE.Vector3(x,y,z));
});

threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$3 = (function (x,y,z){
return (new THREE.Vector3(x,y,z));
});

threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$0 = (function (){
return (new THREE.Vector3());
});

threeagent.impl.threejs.vec3.cljs$lang$maxFixedArity = 3;

threeagent.impl.threejs.arrow_helper = (function threeagent$impl$threejs$arrow_helper(dir,origin,length){
return (new THREE.ArrowHelper(threeagent.impl.threejs.vec3.call(null,dir),threeagent.impl.threejs.vec3.call(null,origin),length));
});
threeagent.impl.threejs.vec3__GT_vector = (function threeagent$impl$threejs$vec3__GT_vector(v){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [v.x,v.y,v.z], null);
});
threeagent.impl.threejs.euler = (function threeagent$impl$threejs$euler(x,y,z){
return (new THREE.Euler(x,y,z,"XYZ"));
});
threeagent.impl.threejs.euler__GT_vector = (function threeagent$impl$threejs$euler__GT_vector(e){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [e.x,e.y,e.z], null);
});
threeagent.impl.threejs.color = (function threeagent$impl$threejs$color(var_args){
var G__23893 = arguments.length;
switch (G__23893) {
case 1:
return threeagent.impl.threejs.color.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 3:
return threeagent.impl.threejs.color.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

threeagent.impl.threejs.color.cljs$core$IFn$_invoke$arity$1 = (function (s){
return (new THREE.Color(s));
});

threeagent.impl.threejs.color.cljs$core$IFn$_invoke$arity$3 = (function (r,g,b){
return (new THREE.Color(r,g,b));
});

threeagent.impl.threejs.color.cljs$lang$maxFixedArity = 3;

threeagent.impl.threejs.raycaster = (function threeagent$impl$threejs$raycaster(origin,dir,near,far){
return (new THREE.Raycaster(origin,dir,near,far));
});
threeagent.impl.threejs.world_position = (function threeagent$impl$threejs$world_position(obj){
if(cljs.core.truth_(obj)){
var v = threeagent.impl.threejs.vec3.call(null);
obj.getWorldPosition(v);

return v;
} else {
return null;
}
});
threeagent.impl.threejs.rotation__GT_direction = (function threeagent$impl$threejs$rotation__GT_direction(obj){
var quat = (new THREE.Quaternion()).setFromRotationMatrix(obj.matrixWorld);
var vector = threeagent.impl.threejs.vec3.call(null,(0),(1),(0));
vector.applyQuaternion(quat);

vector.normalize();

return vector;
});
threeagent.impl.threejs.set_position_BANG_ = (function threeagent$impl$threejs$set_position_BANG_(obj,p__23895){
var vec__23896 = p__23895;
var x = cljs.core.nth.call(null,vec__23896,(0),null);
var y = cljs.core.nth.call(null,vec__23896,(1),null);
var z = cljs.core.nth.call(null,vec__23896,(2),null);
obj.position.set(x,y,z);

return obj;
});
threeagent.impl.threejs.set_rotation_BANG_ = (function threeagent$impl$threejs$set_rotation_BANG_(obj,p__23899){
var vec__23900 = p__23899;
var x = cljs.core.nth.call(null,vec__23900,(0),null);
var y = cljs.core.nth.call(null,vec__23900,(1),null);
var z = cljs.core.nth.call(null,vec__23900,(2),null);
obj.setRotationFromEuler(threeagent.impl.threejs.euler.call(null,x,y,z));

return obj;
});
threeagent.impl.threejs.set_scale_BANG_ = (function threeagent$impl$threejs$set_scale_BANG_(obj,p__23903){
var vec__23904 = p__23903;
var x = cljs.core.nth.call(null,vec__23904,(0),null);
var y = cljs.core.nth.call(null,vec__23904,(1),null);
var z = cljs.core.nth.call(null,vec__23904,(2),null);
obj.scale.set(x,y,z);

return obj;
});
threeagent.impl.threejs.add_child_BANG_ = (function threeagent$impl$threejs$add_child_BANG_(parent,child){
return parent.add(child);
});
threeagent.impl.threejs.remove_child_BANG_ = (function threeagent$impl$threejs$remove_child_BANG_(parent,child){
return parent.remove(child);
});
threeagent.impl.threejs.remove_all_children_BANG_ = (function threeagent$impl$threejs$remove_all_children_BANG_(parent){
var iter__4434__auto___23911 = (function threeagent$impl$threejs$remove_all_children_BANG__$_iter__23907(s__23908){
return (new cljs.core.LazySeq(null,(function (){
var s__23908__$1 = s__23908;
while(true){
var temp__5457__auto__ = cljs.core.seq.call(null,s__23908__$1);
if(temp__5457__auto__){
var s__23908__$2 = temp__5457__auto__;
if(cljs.core.chunked_seq_QMARK_.call(null,s__23908__$2)){
var c__4432__auto__ = cljs.core.chunk_first.call(null,s__23908__$2);
var size__4433__auto__ = cljs.core.count.call(null,c__4432__auto__);
var b__23910 = cljs.core.chunk_buffer.call(null,size__4433__auto__);
if((function (){var i__23909 = (0);
while(true){
if((i__23909 < size__4433__auto__)){
var c = cljs.core._nth.call(null,c__4432__auto__,i__23909);
cljs.core.chunk_append.call(null,b__23910,threeagent.impl.threejs.remove_child_BANG_.call(null,parent,c));

var G__23912 = (i__23909 + (1));
i__23909 = G__23912;
continue;
} else {
return true;
}
break;
}
})()){
return cljs.core.chunk_cons.call(null,cljs.core.chunk.call(null,b__23910),threeagent$impl$threejs$remove_all_children_BANG__$_iter__23907.call(null,cljs.core.chunk_rest.call(null,s__23908__$2)));
} else {
return cljs.core.chunk_cons.call(null,cljs.core.chunk.call(null,b__23910),null);
}
} else {
var c = cljs.core.first.call(null,s__23908__$2);
return cljs.core.cons.call(null,threeagent.impl.threejs.remove_child_BANG_.call(null,parent,c),threeagent$impl$threejs$remove_all_children_BANG__$_iter__23907.call(null,cljs.core.rest.call(null,s__23908__$2)));
}
} else {
return null;
}
break;
}
}),null,null));
});
iter__4434__auto___23911.call(null,parent.children);

return parent;
});

//# sourceMappingURL=threejs.js.map?rel=1547522529369

==> threeagent-0.0.1-20190303.002900-4.jar: public/js/out/threeagent/impl/threejs.js <==
// Compiled by ClojureScript 1.10.439 {}
goog.provide('threeagent.impl.threejs');
goog.require('cljs.core');
goog.require('threeagent.impl.util');
threeagent.impl.threejs.perspective_camera = (function threeagent$impl$threejs$perspective_camera(fov,aspect,near,far){
return (new THREE.PerspectiveCamera(fov,aspect,near,far));
});
threeagent.impl.threejs.point_light = (function threeagent$impl$threejs$point_light(c,i,d){
return (new THREE.PointLight(c,i,d));
});
threeagent.impl.threejs.directional_light = (function threeagent$impl$threejs$directional_light(c,i){
return (new THREE.DirectionalLight(c,i));
});
threeagent.impl.threejs.hemisphere_light = (function threeagent$impl$threejs$hemisphere_light(sky_color,ground_color,intensity){
return (new THREE.HemisphereLight(sky_color,ground_color,intensity));
});
threeagent.impl.threejs.box_geometry = (function threeagent$impl$threejs$box_geometry(x,y,z){
return (new THREE.BoxGeometry(x,y,z));
});
threeagent.impl.threejs.plane_geometry = (function threeagent$impl$threejs$plane_geometry(width,height,segments_width,segments_height){
return (new THREE.PlaneGeometry(width,height,segments_width,segments_height));
});
threeagent.impl.threejs.sphere_geometry = (function threeagent$impl$threejs$sphere_geometry(radius,width_seg,height_seg){
return (new THREE.SphereGeometry(radius,width_seg,height_seg));
});
threeagent.impl.threejs.text_geometry = (function threeagent$impl$threejs$text_geometry(text,cfg){
return (new THREE.TextGeometry(text,cljs.core.clj__GT_js.call(null,cfg)));
});
threeagent.impl.threejs.mesh_basic_material = (function threeagent$impl$threejs$mesh_basic_material(c){
return (new THREE.MeshBasicMaterial(cljs.core.clj__GT_js.call(null,c)));
});
threeagent.impl.threejs.mesh_phong_material = (function threeagent$impl$threejs$mesh_phong_material(c){
return (new THREE.MeshPhongMaterial(cljs.core.clj__GT_js.call(null,c)));
});
threeagent.impl.threejs.mesh = (function threeagent$impl$threejs$mesh(geo,mat){
return (new THREE.Mesh(geo,mat));
});
threeagent.impl.threejs.object = (function threeagent$impl$threejs$object(){
return (new THREE.Object3D());
});
threeagent.impl.threejs.group = (function threeagent$impl$threejs$group(){
return (new THREE.Group());
});
threeagent.impl.threejs.vec3 = (function threeagent$impl$threejs$vec3(var_args){
var G__21818 = arguments.length;
switch (G__21818) {
case 1:
return threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 3:
return threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
case 0:
return threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$0();

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$1 = (function (p__21819){
var vec__21820 = p__21819;
var x = cljs.core.nth.call(null,vec__21820,(0),null);
var y = cljs.core.nth.call(null,vec__21820,(1),null);
var z = cljs.core.nth.call(null,vec__21820,(2),null);
return (new THREE.Vector3(x,y,z));
});

threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$3 = (function (x,y,z){
return (new THREE.Vector3(x,y,z));
});

threeagent.impl.threejs.vec3.cljs$core$IFn$_invoke$arity$0 = (function (){
return (new THREE.Vector3());
});

threeagent.impl.threejs.vec3.cljs$lang$maxFixedArity = 3;

threeagent.impl.threejs.arrow_helper = (function threeagent$impl$threejs$arrow_helper(dir,origin,length){
return (new THREE.ArrowHelper(threeagent.impl.threejs.vec3.call(null,dir),threeagent.impl.threejs.vec3.call(null,origin),length));
});
threeagent.impl.threejs.vec3__GT_vector = (function threeagent$impl$threejs$vec3__GT_vector(v){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [v.x,v.y,v.z], null);
});
threeagent.impl.threejs.euler = (function threeagent$impl$threejs$euler(x,y,z){
return (new THREE.Euler(x,y,z,"XYZ"));
});
threeagent.impl.threejs.euler__GT_vector = (function threeagent$impl$threejs$euler__GT_vector(e){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [e.x,e.y,e.z], null);
});
threeagent.impl.threejs.color = (function threeagent$impl$threejs$color(var_args){
var G__21825 = arguments.length;
switch (G__21825) {
case 1:
return threeagent.impl.threejs.color.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 3:
return threeagent.impl.threejs.color.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

threeagent.impl.threejs.color.cljs$core$IFn$_invoke$arity$1 = (function (s){
return (new THREE.Color(s));
});

threeagent.impl.threejs.color.cljs$core$IFn$_invoke$arity$3 = (function (r,g,b){
return (new THREE.Color(r,g,b));
});

threeagent.impl.threejs.color.cljs$lang$maxFixedArity = 3;

threeagent.impl.threejs.raycaster = (function threeagent$impl$threejs$raycaster(origin,dir,near,far){
return (new THREE.Raycaster(origin,dir,near,far));
});
threeagent.impl.threejs.world_position = (function threeagent$impl$threejs$world_position(obj){
if(cljs.core.truth_(obj)){
var v = threeagent.impl.threejs.vec3.call(null);
obj.getWorldPosition(v);

return v;
} else {
return null;
}
});
threeagent.impl.threejs.rotation__GT_direction = (function threeagent$impl$threejs$rotation__GT_direction(obj){
var quat = (new THREE.Quaternion()).setFromRotationMatrix(obj.matrixWorld);
var vector = threeagent.impl.threejs.vec3.call(null,(0),(1),(0));
vector.applyQuaternion(quat);

vector.normalize();

return vector;
});
threeagent.impl.threejs.set_position_BANG_ = (function threeagent$impl$threejs$set_position_BANG_(obj,p__21827){
var vec__21828 = p__21827;
var x = cljs.core.nth.call(null,vec__21828,(0),null);
var y = cljs.core.nth.call(null,vec__21828,(1),null);
var z = cljs.core.nth.call(null,vec__21828,(2),null);
obj.position.set(x,y,z);

return obj;
});
threeagent.impl.threejs.set_rotation_BANG_ = (function threeagent$impl$threejs$set_rotation_BANG_(obj,p__21831){
var vec__21832 = p__21831;
var x = cljs.core.nth.call(null,vec__21832,(0),null);
var y = cljs.core.nth.call(null,vec__21832,(1),null);
var z = cljs.core.nth.call(null,vec__21832,(2),null);
obj.setRotationFromEuler(threeagent.impl.threejs.euler.call(null,x,y,z));

return obj;
});
threeagent.impl.threejs.set_scale_BANG_ = (function threeagent$impl$threejs$set_scale_BANG_(obj,p__21835){
var vec__21836 = p__21835;
var x = cljs.core.nth.call(null,vec__21836,(0),null);
var y = cljs.core.nth.call(null,vec__21836,(1),null);
var z = cljs.core.nth.call(null,vec__21836,(2),null);
obj.scale.set(x,y,z);

return obj;
});
threeagent.impl.threejs.add_child_BANG_ = (function threeagent$impl$threejs$add_child_BANG_(parent,child){
return parent.add(child);
});
threeagent.impl.threejs.remove_child_BANG_ = (function threeagent$impl$threejs$remove_child_BANG_(parent,child){
return parent.remove(child);
});
threeagent.impl.threejs.remove_all_children_BANG_ = (function threeagent$impl$threejs$remove_all_children_BANG_(parent){
var iter__4434__auto___21843 = (function threeagent$impl$threejs$remove_all_children_BANG__$_iter__21839(s__21840){
return (new cljs.core.LazySeq(null,(function (){
var s__21840__$1 = s__21840;
while(true){
var temp__5457__auto__ = cljs.core.seq.call(null,s__21840__$1);
if(temp__5457__auto__){
var s__21840__$2 = temp__5457__auto__;
if(cljs.core.chunked_seq_QMARK_.call(null,s__21840__$2)){
var c__4432__auto__ = cljs.core.chunk_first.call(null,s__21840__$2);
var size__4433__auto__ = cljs.core.count.call(null,c__4432__auto__);
var b__21842 = cljs.core.chunk_buffer.call(null,size__4433__auto__);
if((function (){var i__21841 = (0);
while(true){
if((i__21841 < size__4433__auto__)){
var c = cljs.core._nth.call(null,c__4432__auto__,i__21841);
cljs.core.chunk_append.call(null,b__21842,threeagent.impl.threejs.remove_child_BANG_.call(null,parent,c));

var G__21844 = (i__21841 + (1));
i__21841 = G__21844;
continue;
} else {
return true;
}
break;
}
})()){
return cljs.core.chunk_cons.call(null,cljs.core.chunk.call(null,b__21842),threeagent$impl$threejs$remove_all_children_BANG__$_iter__21839.call(null,cljs.core.chunk_rest.call(null,s__21840__$2)));
} else {
return cljs.core.chunk_cons.call(null,cljs.core.chunk.call(null,b__21842),null);
}
} else {
var c = cljs.core.first.call(null,s__21840__$2);
return cljs.core.cons.call(null,threeagent.impl.threejs.remove_child_BANG_.call(null,parent,c),threeagent$impl$threejs$remove_all_children_BANG__$_iter__21839.call(null,cljs.core.rest.call(null,s__21840__$2)));
}
} else {
return null;
}
break;
}
}),null,null));
});
iter__4434__auto___21843.call(null,parent.children);

return parent;
});

//# sourceMappingURL=threejs.js.map?rel=1550945896094
